pub struct EffectRegistry { /* private fields */ }Expand description
Effect registry - stores available effects and their processors
Implementations
Sourceimpl EffectRegistry
impl EffectRegistry
pub fn new() -> Self
Sourcepub fn register_effect(
&mut self,
name: &'static str,
availability: EffectAvailability,
processor: Box<dyn CloneableEffect>,
)
pub fn register_effect( &mut self, name: &'static str, availability: EffectAvailability, processor: Box<dyn CloneableEffect>, )
Register a new effect with its availability and processor
Sourcepub fn get_effect(
&self,
name: &str,
synth_context: bool,
) -> Option<Box<dyn CloneableEffect>>
pub fn get_effect( &self, name: &str, synth_context: bool, ) -> Option<Box<dyn CloneableEffect>>
Get an effect processor by name if it’s available for the given context
Sourcepub fn is_effect_available(&self, name: &str, synth_context: bool) -> bool
pub fn is_effect_available(&self, name: &str, synth_context: bool) -> bool
Check if an effect exists and is available in the given context
Sourcepub fn list_available_effects(&self, synth_context: bool) -> Vec<&'static str>
pub fn list_available_effects(&self, synth_context: bool) -> Vec<&'static str>
List all available effects for a given context