AudioEventList

Struct AudioEventList 

pub struct AudioEventList {
    pub events: Vec<AudioEvent>,
    pub logs: Vec<(f32, String)>,
    pub synths: HashMap<String, SynthDefinition>,
}
Audio events collector

Fields

events: Vec<AudioEvent>logs: Vec<(f32, String)>

Print/log messages recorded during interpretation. These are not audio events and should not affect loop termination logic.

synths: HashMap<String, SynthDefinition>

Implementations

Source

impl AudioEventList

pub fn new() -> Self

pub fn add_synth(&mut self, name: String, definition: SynthDefinition)

pub fn add_note_event( &mut self, synth_id: &str, midi: u8, start_time: f32, duration: f32, velocity: f32, pan: f32, detune: f32, gain: f32, attack: Option<f32>, release: Option<f32>, delay_time: Option<f32>, delay_feedback: Option<f32>, delay_mix: Option<f32>, reverb_amount: Option<f32>, drive_amount: Option<f32>, drive_color: Option<f32>, )

pub fn add_chord_event( &mut self, synth_id: &str, midis: Vec<u8>, start_time: f32, duration: f32, velocity: f32, pan: f32, detune: f32, spread: f32, gain: f32, attack: Option<f32>, release: Option<f32>, delay_time: Option<f32>, delay_feedback: Option<f32>, delay_mix: Option<f32>, reverb_amount: Option<f32>, drive_amount: Option<f32>, drive_color: Option<f32>, )

pub fn add_sample_event(&mut self, uri: &str, start_time: f32, velocity: f32)

pub fn add_sample_event_with_effects( &mut self, uri: &str, start_time: f32, velocity: f32, effects: Option<Value>, )

Add a sample event with an attached effects map (owned)

pub fn add_log_event(&mut self, message: String, time: f32)

Add a log message (created by print statements). Time is in seconds from start. Logs are stored separately from audio events so they don’t affect rendering/loop logic.

pub fn get_synth(&self, name: &str) -> Option<&SynthDefinition>

pub fn total_duration(&self) -> f32

pub fn merge(&mut self, other: AudioEventList)

Merge another AudioEventList into this one This is used for parallel spawn execution