Module generator

Module generator 

Structs

FilterDef
Filter definition
SynthParams
Parameters for synthesizing a note

Functions

generate_chord
Generate stereo audio samples for a chord (multiple notes)
generate_chord_with_options
Generate stereo audio samples for a chord with pan, detune and spread options
generate_note
Generate stereo audio samples for a single note
generate_note_with_options
Generate stereo audio samples for a single note with pan and detune options