pub fn generate_note_with_options(
midi_note: u8,
duration_ms: f32,
velocity: f32,
params: &SynthParams,
sample_rate: u32,
pan: f32,
detune: f32,
) -> Result<Vec<f32>>Expand description
Generate stereo audio samples for a single note with pan and detune options
If params contains plugin information, it will use the WASM plugin instead of built-in synth