Functions
- call_
function - Execute a call as an expression and return its resulting Value.
This is similar to
handle_callbut returns the capturedreturnvalue from a function when present. Groups and patterns returnValue::Null. - execute_
event_ handlers - execute_
if - execute_
pattern - execute_
pattern_ with_ source - execute_
print - execute_
while - extract_
pattern_ data - extract_
synth_ def_ from_ map - handle_
assign - handle_
bank - handle_
bind - handle_
call - handle_
fade - Handle fade statement: automate a parameter in or out over a duration
- handle_
let - handle_
load - handle_
stop - Handle stop statement: cease audio playback
- handle_
trigger - handle_
use_ plugin - resolve_
sample_ uri