call_function

Function call_function 

pub fn call_function(
    interpreter: &mut AudioInterpreter,
    name: &str,
    args: &[Value],
) -> Result<Value>
Execute a call as an expression and return its resulting Value. This is similar to handle_call but returns the captured return value from a function when present. Groups and patterns return Value::Null.