Constants
Functions
- ensure_
deva_ dir - Ensures the
.devadirectory exists in the project root and returns its path. - ensure_
home_ deva_ dir - Ensures the home directory’s .deva exists
- find_
project_ root - Finds the project root from the current working directory.
- find_
project_ root_ from - Walks upward from
startto locate the first directory considered a project root. - get_cwd
- Returns the current working directory.
- get_
deva_ dir - Returns the
.devadirectory inside the project root (without creating it). - get_
home_ deva_ dir - Gets the home directory’s .deva (for user-level addons)
- get_
project_ root - Gets the project root or returns an error if not found.
- is_
project_ root - Returns true if the given directory looks like a devalang project root.
Checks for the presence of
.devalangconfig file or.devadirectory.