Module handler

Module handler 

Functions

call_function
Execute a call as an expression and return its resulting Value. This is similar to handle_call but returns the captured return value from a function when present. Groups and patterns return Value::Null.
execute_event_handlers
execute_if
execute_pattern
execute_print
extract_pattern_data
extract_synth_def_from_map
handle_assign
handle_bank
handle_bind
handle_call
handle_let
handle_load
handle_trigger
handle_use_plugin
resolve_sample_uri