Functions
- call_
function - Execute a call as an expression and return its resulting Value.
This is similar to
handle_callbut returns the capturedreturnvalue from a function when present. Groups and patterns returnValue::Null. - execute_
event_ handlers - execute_
if - execute_
pattern - execute_
print - extract_
pattern_ data - extract_
synth_ def_ from_ map - handle_
assign - handle_
bank - handle_
bind - handle_
call - handle_
let - handle_
load - handle_
trigger - handle_
use_ plugin - resolve_
sample_ uri